"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.importFunction = exports.aliases = exports.builder = exports.desc = exports.command = void 0;
const debugLib = require("debug");
const _ = require("lodash");
const yargs = require("yargs");
const debug = debugLib('snyk:import-projects-script');
const import_projects_1 = require("../scripts/import-projects");
const lib_1 = require("../lib");
const lib_2 = require("../lib");
exports.command = ['import', '$0'];
exports.desc = 'Kick off API powered import';
exports.builder = {
    file: {
        required: false,
        default: undefined,
        desc: 'Path to json file that contains the targets to be imported',
    },
};
exports.aliases = ['i'];
async function importFunction(file) {
    try {
        const logsPath = lib_2.getLoggingPath();
        const importFile = lib_1.getImportProjectsFile(file);
        const { projects, filteredTargets, targets, skippedTargets, logFile } = await import_projects_1.importProjects(importFile);
        const projectsMessage = projects.length > 0
            ? `Imported ${_.uniqBy(projects, 'projectUrl').length} project(s)`
            : '⚠ No projects imported!';
        const targetsMessage = `\nProcessed ${filteredTargets.length} out of a total of ${targets.length} targets${skippedTargets
            ? ` (${skippedTargets} were skipped as they have been previously imported).`
            : ''}`;
        const message = `${projectsMessage}${targetsMessage}\nCheck the logs for any failures located at:  ${logsPath}/*`;
        return {
            fileName: logFile,
            exitCode: 0,
            message: message,
        };
    }
    catch (e) {
        const errorMessage = `ERROR! Failed to kick off import with error: ${e.message}\n Try running with \`DEBUG=snyk* snyk-import\` for more information`;
        return {
            fileName: undefined,
            exitCode: 1,
            message: errorMessage,
        };
    }
}
exports.importFunction = importFunction;
async function handler(argv) {
    const { file } = argv;
    debug('ℹ️  Options: ' + JSON.stringify(argv));
    const res = await importFunction(file);
    if (res.exitCode === 1) {
        debug('Failed to import projects.\n' + res.message);
        console.error(res.message);
        yargs.exit(1, new Error(res.message));
    }
    else {
        console.log(res.message);
    }
}
exports.handler = handler;
//# sourceMappingURL=import.js.map