"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getFeatureFlag = void 0;
const debugLib = require("debug");
const debug = debugLib('snyk:get-feature-flag');
async function getFeatureFlag(requestManager, featureFlagName, orgId) {
    var _a, _b, _c, _d;
    debug(`Checking if feature flag ${featureFlagName} is enabled for Snyk org ${orgId}`);
    try {
        const url = `cli-config/feature-flags/${featureFlagName}?org=${orgId}`;
        const res = await requestManager.request({
            verb: 'get',
            url: url,
            useRESTApi: false,
        });
        debug(`Feature flag ${featureFlagName} is enabled for Org ${orgId}`);
        const enabled = res.data['ok'];
        return enabled;
    }
    catch (err) {
        const res = (_b = (_a = err.message) === null || _a === void 0 ? void 0 : _a.response) === null || _b === void 0 ? void 0 : _b.data;
        const message = (res === null || res === void 0 ? void 0 : res.userMessage) || (res === null || res === void 0 ? void 0 : res.message) || ((_c = err.message) === null || _c === void 0 ? void 0 : _c.message);
        if (res &&
            res.ok === false &&
            ((_d = res === null || res === void 0 ? void 0 : res.userMessage) === null || _d === void 0 ? void 0 : _d.includes('feature enabled'))) {
            debug(`Feature flag ${featureFlagName} is not enabled for Org ${orgId}`);
            return false;
        }
        debug(`Could not fetch the ${featureFlagName} feature flag for ${orgId}. Error: ${JSON.stringify(err)}`);
        throw new Error(`Could not fetch the ${featureFlagName} feature flag for ${orgId}. ${message}`);
    }
}
exports.getFeatureFlag = getFeatureFlag;
//# sourceMappingURL=index.js.map