"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAllOrgs = exports.listOrgsPerPage = exports.listOrgs = exports.createOrg = void 0;
require("source-map-support/register");
const debugLib = require("debug");
const qs = require("querystring");
const get_api_token_1 = require("../../get-api-token");
const get_snyk_host_1 = require("../../get-snyk-host");
const debug = debugLib('snyk:api-group');
async function createOrg(requestManager, groupId, name, sourceOrgId) {
    get_api_token_1.getApiToken();
    get_snyk_host_1.getSnykHost();
    debug(`Creating a new org: "${name}"`);
    if (!groupId || !name) {
        throw new Error(`Missing required parameters. Please ensure you have set: groupId, name.
      \nFor more information see: https://snyk.docs.apiary.io/#reference/0/organizations-in-groups/create-a-new-organization-in-the-group`);
    }
    const body = {
        name,
        groupId,
        sourceOrgId,
    };
    const res = await requestManager.request({
        verb: 'post',
        url: `/org`,
        body: JSON.stringify(body),
    });
    const statusCode = res.statusCode || res.status;
    if (!statusCode || statusCode !== 201) {
        throw new Error('Expected a 201 response, instead received: ' +
            JSON.stringify({ data: res.data, status: statusCode }));
    }
    return res.data;
}
exports.createOrg = createOrg;
async function listOrgs(requestManager, groupId, params) {
    if (!groupId) {
        throw new Error('Missing required param groupId');
    }
    const query = qs.stringify(params);
    const res = await requestManager.request({
        verb: 'get',
        url: `/group/${groupId}/orgs?query=${query}`,
        body: JSON.stringify({}),
    });
    const statusCode = res.statusCode || res.status;
    if (!statusCode || statusCode !== 200) {
        throw new Error('Expected a 200 response, instead received: ' +
            JSON.stringify({ statusCode, data: res.data }));
    }
    const data = res.data;
    const orgs = data.orgs.map((org) => ({
        ...org,
        group: {
            name: res.data.name,
            url: res.data.url,
            id: res.data.id,
        },
    }));
    return orgs;
}
exports.listOrgs = listOrgs;
async function listOrgsPerPage(requestManager, groupId, pageNumber = 1, perPage = 100) {
    const data = [];
    const params = {
        perPage,
        page: pageNumber,
    };
    const orgs = await listOrgs(requestManager, groupId, params);
    const hasNextPage = orgs.length ? true : false;
    data.push(...orgs);
    return { orgs: data, hasNextPage };
}
exports.listOrgsPerPage = listOrgsPerPage;
async function getAllOrgs(requestManager, groupId) {
    const orgData = [];
    let currentPage = 0;
    let hasMorePages = true;
    while (hasMorePages) {
        currentPage = currentPage + 1;
        debug(`Fetching page: ${currentPage}`);
        const { orgs, hasNextPage } = await listOrgsPerPage(requestManager, groupId, currentPage);
        hasMorePages = hasNextPage;
        orgData.push(...orgs);
    }
    return orgData;
}
exports.getAllOrgs = getAllOrgs;
//# sourceMappingURL=index.js.map