"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.requestWithRateLimitHandling = void 0;
require("source-map-support/register");
const debugLib = require("debug");
const debug = debugLib('snyk:api-import');
async function requestWithRateLimitHandling(requestManager, url, verb, body = {}) {
    const maxRetries = 7;
    let attempt = 0;
    let res;
    debug('Requesting import with retry');
    while (attempt < maxRetries) {
        try {
            res = await requestManager.request({
                verb,
                url,
                body: JSON.stringify(body),
            });
            break;
        }
        catch (e) {
            res = e;
            if (e.data.code === 401) {
                console.error(`ERROR: ${e.data.message}. Please check the token and try again.`);
                break;
            }
            if ([404, 504, 400].includes(e.data.code)) {
                break;
            }
            attempt += 1;
            debug('Failed:' + JSON.stringify(e));
            if (e.data.code === 429) {
                const sleepTime = 600000 * attempt; // 10 mins x attempt with a max of ~ 1hr
                console.error(`Received a rate limit error, sleeping for ${sleepTime} ms (attempt # ${attempt})`);
                await new Promise((r) => setTimeout(r, sleepTime));
            }
        }
    }
    return res;
}
exports.requestWithRateLimitHandling = requestWithRateLimitHandling;
//# sourceMappingURL=request-with-rate-limit.js.map