"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.updateProject = exports.deactivateProject = exports.deleteProjects = void 0;
require("source-map-support/register");
const needle = require("needle");
const debugLib = require("debug");
const get_api_token_1 = require("../../get-api-token");
const get_snyk_host_1 = require("../../get-snyk-host");
const debug = debugLib('snyk:api-project');
async function deleteProjects(orgId, projects) {
    const apiToken = get_api_token_1.getApiToken();
    if (!(orgId && projects)) {
        throw new Error(`Missing required parameters. Please ensure you have provided: orgId & projectIds.`);
    }
    debug('Deleting projectIds:', projects.join(', '));
    try {
        const SNYK_API = get_snyk_host_1.getSnykHost();
        const body = {
            projects,
        };
        const res = await needle('post', `${SNYK_API}/org/${orgId.trim()}/projects/bulk-delete`, body, {
            json: true,
            // eslint-disable-next-line @typescript-eslint/camelcase
            read_timeout: 30000,
            headers: {
                'content-type': 'application/json',
                Authorization: `token ${apiToken}`,
            },
        });
        const statusCode = res.statusCode;
        if (!statusCode || statusCode !== 200) {
            throw new Error(`Expected a 200 response, instead received statusCode: ${res.statusCode},
          body: ${JSON.stringify(res.body)}`);
        }
        return res.body;
    }
    catch (error) {
        debug('Could not delete project:', error.message || error);
        const err = new Error('Could not delete project');
        err.innerError = error;
        throw err;
    }
}
exports.deleteProjects = deleteProjects;
async function deactivateProject(requestManager, orgId, projectPublicId) {
    get_api_token_1.getApiToken();
    get_snyk_host_1.getSnykHost();
    if (!(orgId && projectPublicId)) {
        throw new Error(`Missing required parameters. Please ensure you have provided: orgId & projectId.`);
    }
    debug(`De-activating project: ${projectPublicId}`);
    const url = `/org/${orgId.trim()}/project/${projectPublicId}/deactivate`;
    const res = await requestManager.request({
        verb: 'post',
        url: url,
        body: JSON.stringify({}),
        useRESTApi: false,
    });
    const statusCode = res.statusCode || res.status;
    if (!statusCode || statusCode !== 200) {
        debug(`Failed de-activating project projectId`);
        throw new Error('Expected a 200 response, instead received: ' +
            JSON.stringify({ data: res.data, status: statusCode }));
    }
    debug('Updated projects batch');
    return true;
}
exports.deactivateProject = deactivateProject;
async function updateProject(requestManager, orgId, projectId, config) {
    get_api_token_1.getApiToken();
    get_snyk_host_1.getSnykHost();
    if (!orgId || !projectId) {
        throw new Error(`Missing required parameters. Please ensure you have set: orgId and projectId.
      \nFor more information see: https://snyk.docs.apiary.io/reference/projects/individual-project/update-a-project`);
    }
    const body = {
        branch: config.branch,
    };
    const url = `/org/${orgId.trim()}/project/${projectId.trim()}`;
    const res = await requestManager.request({
        verb: 'put',
        url: url,
        body: JSON.stringify(body),
        useRESTApi: false,
    });
    const statusCode = res.statusCode || res.status;
    if (!statusCode || statusCode !== 200) {
        debug('Failed updating project: ' + projectId);
        throw new Error('Expected a 200 response, instead received: ' +
            JSON.stringify({ data: res.data, status: statusCode }));
    }
    const updatedProject = res.data;
    debug('Updated project: ' + projectId);
    return updatedProject;
}
exports.updateProject = updateProject;
//# sourceMappingURL=index.js.map