"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.filterOutExistingOrgs = void 0;
const group_1 = require("./api/group");
async function filterOutExistingOrgs(requestManager, orgs = [], groupId) {
    if (!groupId) {
        throw new Error('Missing required param groupId');
    }
    if (orgs.length === 0) {
        return { existingOrgs: [], newOrgs: [] };
    }
    const existingOrgs = [];
    const newOrgs = [];
    const groupOrgs = await group_1.getAllOrgs(requestManager, groupId);
    const uniqueOrgNames = new Set(groupOrgs.map((org) => org.name));
    for (const org of orgs) {
        if (!uniqueOrgNames.has(org.name)) {
            newOrgs.push(org);
        }
    }
    if (existingOrgs.length > 0) {
        console.log(`Skipped creating ${existingOrgs.length} organization(s) as the names were already used in the Group ${groupId}. Organizations skipped: ${existingOrgs
            .map((o) => o.name)
            .join(', ')}`);
    }
    return { existingOrgs: groupOrgs, newOrgs };
}
exports.filterOutExistingOrgs = filterOutExistingOrgs;
//# sourceMappingURL=filter-out-existing-orgs.js.map