"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getImportProjectsFile = void 0;
const fs = require("fs");
const path = require("path");
function getImportProjectsFile(filePath) {
    const triedFileLocations = [];
    const snykImportPath = filePath !== null && filePath !== void 0 ? filePath : process.env.SNYK_IMPORT_PATH;
    if (!snykImportPath) {
        throw new Error(`Please set the SNYK_IMPORT_PATH environment variable (for example export SNYK_IMPORT_PATH='~/my/path/to/file') or set it with --file='~/my/path/to/file'`);
    }
    const { ext, base } = path.parse(snykImportPath);
    const jsonFileName = ext === '.json' ? base : undefined;
    const absolutePath = jsonFileName
        ? path.resolve(process.cwd(), snykImportPath)
        : undefined;
    if (absolutePath) {
        triedFileLocations.push(absolutePath);
        // if it looks like a path to file return the path
        if (fs.existsSync(absolutePath)) {
            return absolutePath;
        }
    }
    // if it looks like a directory
    // assume file name
    const defaultFile = path.resolve(process.cwd(), snykImportPath, 'import-projects.json');
    triedFileLocations.push(defaultFile);
    if (fs.existsSync(defaultFile)) {
        return defaultFile;
    }
    throw new Error(`Could not find the import file, locations tried:${triedFileLocations.join(',')}. Please set the location via --file or SNYK_IMPORT_PATH e.g. export SNYK_IMPORT_PATH='~/my/path/to/import-projects.json'`);
}
exports.getImportProjectsFile = getImportProjectsFile;
//# sourceMappingURL=get-import-path.js.map