"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.gitClone = void 0;
const debugLib = require("debug");
const fs = require("fs");
const path = require("path");
const os = require("os");
const simple_git_1 = require("simple-git");
const github = require("../lib/source-handlers/github");
const types_1 = require("./types");
const delete_directory_1 = require("./delete-directory");
const debug = debugLib('snyk:git-clone');
const urlGenerators = {
    [types_1.SupportedIntegrationTypesUpdateProject.GITHUB]: github.buildGitCloneUrl,
    [types_1.SupportedIntegrationTypesUpdateProject.GHE]: github.buildGitCloneUrl,
};
async function gitClone(integrationType, meta) {
    const repoClonePath = await fs.mkdtempSync(path.join(os.tmpdir(), `snyk-clone-${Date.now()}-${Math.random()}`));
    try {
        const cloneUrl = urlGenerators[integrationType](meta);
        const options = {
            baseDir: repoClonePath,
            binary: 'git',
            maxConcurrentProcesses: 6,
            trimmed: false,
        };
        debug(`Trying to shallow clone repo: ${meta.cloneUrl}`);
        const git = simple_git_1.simpleGit(options);
        const output = await git.clone(cloneUrl, repoClonePath, {
            '--depth': '1',
            '--branch': meta.branch,
        });
        debug(`Repo ${meta.cloneUrl} was cloned`);
        return {
            gitResponse: output,
            success: true,
            repoPath: repoClonePath,
        };
    }
    catch (err) {
        debug(`Could not shallow clone the repo:\n ${err}`);
        if (fs.existsSync(repoClonePath)) {
            await delete_directory_1.deleteDirectory(repoClonePath);
        }
        return {
            success: false,
            gitResponse: err.message,
        };
    }
}
exports.gitClone = gitClone;
//# sourceMappingURL=git-clone.js.map