"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.limiterWithRateLimitRetries = void 0;
const needle = require("needle");
const debugLib = require("debug");
const debug = debugLib('snyk:limiter');
async function limiterWithRateLimitRetries(verb, url, headers, limiter, rateLimitSleepTime) {
    let data;
    const maxRetries = 7;
    let attempt = 0;
    const encodedUrl = encodeURI(url);
    limiter.on('failed', async (error, jobInfo) => {
        const id = jobInfo.options.id;
        debug(`Job ${id} failed: ${error}`);
        if (jobInfo.retryCount === 0) {
            // Here we only retry once
            debug(`Retrying job ${id} in 25ms!`);
            return 25;
        }
    });
    while (attempt < maxRetries) {
        data = (await limiter.schedule(() => needle(verb, encodedUrl, { headers: headers })));
        if ([404, 200].includes(Number(data.statusCode))) {
            break;
        }
        if (data.statusCode === 401) {
            console.error(`ERROR: ${JSON.stringify(data.body)}. Please check the token and try again.`);
            break;
        }
        if (data.statusCode === 429) {
            const sleepTime = (rateLimitSleepTime || 60000) * attempt; // 10 mins x attempt with a max of ~ 1hr
            console.error(`Received a rate limit error, sleeping for ${sleepTime} ms (attempt # ${attempt})`);
            await new Promise((r) => setTimeout(r, sleepTime));
        }
        attempt += 1;
    }
    return data;
}
exports.limiterWithRateLimitRetries = limiterWithRateLimitRetries;
//# sourceMappingURL=request-with-rate-limit.js.map