"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.listAzureRepos = exports.fetchAllRepos = void 0;
const base64 = require("base-64");
const debugLib = require("debug");
const get_azure_token_1 = require("./get-azure-token");
const list_projects_1 = require("./list-projects");
const get_base_url_1 = require("./get-base-url");
const request_with_rate_limit_1 = require("../../request-with-rate-limit");
const limiters_1 = require("../../limiters");
const debug = debugLib('snyk:azure');
async function fetchAllRepos(url, orgName, project, token) {
    debug('Fetching repos for ' + project.name);
    let repoList = [];
    try {
        repoList = await getRepos(url, orgName, project.id, token);
    }
    catch (err) {
        throw new Error(JSON.stringify(err));
    }
    return repoList;
}
exports.fetchAllRepos = fetchAllRepos;
async function getRepos(url, orgName, projectId, token) {
    const repoList = [];
    const headers = {
        Authorization: `Basic ${base64.encode(':' + token)}`,
    };
    const limiter = await limiters_1.limiterForScm(1, 500);
    const { body, statusCode } = await request_with_rate_limit_1.limiterWithRateLimitRetries('get', `${url}/${orgName}/${projectId}/_apis/git/repositories?api-version=4.1`, headers, limiter, 60000);
    if (statusCode != 200) {
        throw new Error(`Failed to fetch repos for ${url}/${orgName}/${projectId}/_apis/git/repositories?api-version=4.1\n
    Status Code: ${statusCode}\n
    Response body: ${JSON.stringify(body)}`);
    }
    const { value: repos } = body;
    repos.map((repo) => {
        const { name, project, defaultBranch } = repo;
        if (name && project && project.name && defaultBranch) {
            repoList.push({
                name,
                owner: project.name,
                branch: defaultBranch,
            });
        }
    });
    return repoList;
}
async function listAzureRepos(orgName, host) {
    const azureToken = get_azure_token_1.getAzureToken();
    const baseUrl = get_base_url_1.getBaseUrl(host);
    const repoList = [];
    debug(`Fetching all repos data for org: ${orgName}`);
    const projectList = await list_projects_1.listAzureProjects(orgName, baseUrl);
    for (const project of projectList) {
        repoList.push(...(await fetchAllRepos(baseUrl, orgName, { name: project.name, id: project.id }, azureToken)));
    }
    return repoList;
}
exports.listAzureRepos = listAzureRepos;
//# sourceMappingURL=list-repos.js.map