"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.listBitbucketCloudRepos = exports.fetchAllBitbucketCloudRepos = void 0;
const debugLib = require("debug");
const base64 = require("base-64");
const get_bitbucket_cloud_username_1 = require("./get-bitbucket-cloud-username");
const get_bitbucket_cloud_password_1 = require("./get-bitbucket-cloud-password");
const limiters_1 = require("../../limiters");
const request_with_rate_limit_1 = require("../../request-with-rate-limit");
const debug = debugLib('snyk:bitbucket-cloud');
const fetchAllBitbucketCloudRepos = async (workspace, username, password) => {
    let lastPage = false;
    let reposList = [];
    let pageCount = 1;
    let nextPage;
    while (!lastPage) {
        debug(`Fetching page ${pageCount} for ${workspace}\n`);
        try {
            const { repos, next, } = await getRepos(workspace, username, password, nextPage);
            reposList = reposList.concat(repos);
            next
                ? ((lastPage = false), (nextPage = next))
                : ((lastPage = true), (nextPage = ''));
            pageCount++;
        }
        catch (err) {
            throw new Error(JSON.stringify(err));
        }
    }
    return reposList;
};
exports.fetchAllBitbucketCloudRepos = fetchAllBitbucketCloudRepos;
const getRepos = async (workspace, username, password, nextPageLink) => {
    const repos = [];
    const headers = {
        Authorization: `Basic ${base64.encode(username + ':' + password)}`,
    };
    const limiter = await limiters_1.limiterForScm(1, 1000, 1000, 1000, 1000 * 3600);
    const { statusCode, body } = await request_with_rate_limit_1.limiterWithRateLimitRetries('get', nextPageLink !== null && nextPageLink !== void 0 ? nextPageLink : `https://bitbucket.org/api/2.0/repositories/${workspace}?pagelen=100`, headers, limiter, 60000);
    if (statusCode != 200) {
        throw new Error(`Failed to fetch projects for ${nextPageLink != ''
            ? nextPageLink
            : `https://bitbucket.org/api/2.0/repositories/${workspace}?pagelen=100`}\n
      Status Code: ${statusCode}\n
      Response body: ${JSON.stringify(body)}`);
    }
    const { next, values } = body;
    for (const repo of values) {
        const { workspace, mainbranch, slug } = repo;
        if (mainbranch.name && workspace && slug)
            repos.push({
                owner: workspace.slug ? workspace.slug : repo.workspace.uuid,
                name: slug,
                branch: mainbranch.name,
            });
    }
    return { repos, next };
};
async function listBitbucketCloudRepos(workspace) {
    const bitbucketCloudUsername = get_bitbucket_cloud_username_1.getBitbucketCloudUsername();
    const bitbucketCloudPassword = get_bitbucket_cloud_password_1.getBitbucketCloudPassword();
    debug(`Fetching all repos data for org: ${workspace}`);
    const repoList = await exports.fetchAllBitbucketCloudRepos(workspace, bitbucketCloudUsername, bitbucketCloudPassword);
    return repoList;
}
exports.listBitbucketCloudRepos = listBitbucketCloudRepos;
//# sourceMappingURL=list-repos.js.map