"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.listBitbucketCloudWorkspaces = exports.getWorkspaces = exports.fetchAllWorkspaces = void 0;
const debugLib = require("debug");
const base64 = require("base-64");
const get_bitbucket_cloud_username_1 = require("./get-bitbucket-cloud-username");
const get_bitbucket_cloud_password_1 = require("./get-bitbucket-cloud-password");
const limiters_1 = require("../../limiters");
const request_with_rate_limit_1 = require("../../request-with-rate-limit");
const debug = debugLib('snyk:bitbucket-cloud');
async function fetchAllWorkspaces(username, password) {
    let lastPage = false;
    let workspacesList = [];
    let pageCount = 1;
    let nextPageLink = undefined;
    while (!lastPage) {
        debug(`Fetching page ${pageCount}\n`);
        try {
            const { workspaces, next, } = await getWorkspaces(username, password, nextPageLink);
            workspacesList = workspacesList.concat(workspaces);
            next
                ? ((lastPage = false), (nextPageLink = next))
                : ((lastPage = true), (nextPageLink = ''));
            pageCount++;
        }
        catch (err) {
            throw new Error(JSON.stringify(err));
        }
    }
    return workspacesList;
}
exports.fetchAllWorkspaces = fetchAllWorkspaces;
async function getWorkspaces(username, password, nextPageLink) {
    const workspaces = [];
    const headers = {
        Authorization: `Basic ${base64.encode(username + ':' + password)}`,
    };
    const limiter = await limiters_1.limiterForScm(1, 1000, 1000, 1000, 1000 * 3600);
    const workspacesUrl = nextPageLink !== null && nextPageLink !== void 0 ? nextPageLink : 'https://bitbucket.org/api/2.0/workspaces?pagelen=100';
    const { statusCode, body } = await request_with_rate_limit_1.limiterWithRateLimitRetries('get', workspacesUrl, headers, limiter, 60000);
    if (statusCode != 200) {
        throw new Error(`Failed to fetch ${workspacesUrl}\n
      Status Code: ${statusCode}\n
      Response body: ${JSON.stringify(body)}`);
    }
    const { values, next } = body;
    for (const workspace of values) {
        workspaces.push({
            name: workspace.slug,
            slug: workspace.slug,
            uuid: workspace.uuid,
        });
    }
    return { workspaces, next };
}
exports.getWorkspaces = getWorkspaces;
async function listBitbucketCloudWorkspaces() {
    const bitbucketCloudUsername = get_bitbucket_cloud_username_1.getBitbucketCloudUsername();
    const bitbucketCloudPassword = get_bitbucket_cloud_password_1.getBitbucketCloudPassword();
    debug(`Fetching all workspaces data`);
    const workspaces = await fetchAllWorkspaces(bitbucketCloudUsername, bitbucketCloudPassword);
    return workspaces;
}
exports.listBitbucketCloudWorkspaces = listBitbucketCloudWorkspaces;
//# sourceMappingURL=list-workspaces.js.map