"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.listBitbucketServerProjects = void 0;
const debugLib = require("debug");
const get_bitbucket_server_token_1 = require("./get-bitbucket-server-token");
const request_with_rate_limit_1 = require("../../request-with-rate-limit");
const limiters_1 = require("../../limiters");
const debug = debugLib('snyk:bitbucket-server');
const fetchAllProjects = async (url, token) => {
    let lastPage = false;
    let projectsList = [];
    let pageCount = 1;
    let startFrom = 0;
    const limit = 100;
    while (!lastPage) {
        debug(`Fetching page ${pageCount} for projects\n`);
        try {
            const { projects, isLastPage, start } = await getProjects(url, token, startFrom, limit);
            lastPage = isLastPage;
            startFrom = start;
            projectsList = projectsList.concat(projects);
            pageCount++;
        }
        catch (err) {
            throw new Error(JSON.stringify(err));
        }
    }
    return projectsList;
};
const getProjects = async (url, token, startFrom, limit) => {
    const headers = { Authorization: `Bearer ${token}` };
    const limiter = await limiters_1.limiterForScm(1, 1000, 1000, 1000, 1000 * 3600);
    const { body, statusCode } = await request_with_rate_limit_1.limiterWithRateLimitRetries('get', `${url}/rest/api/1.0/projects?start=${startFrom}&limit=${limit}`, headers, limiter, 60000);
    if (statusCode != 200) {
        throw new Error(`Failed to fetch projects for ${url}/rest/api/1.0/projects?start=${startFrom}&limit=${limit}\n
    Status Code: ${statusCode}\n
    Response body: ${JSON.stringify(body)}`);
    }
    const { values: projects = [], nextPageStart, isLastPage } = body;
    const start = nextPageStart || -1;
    return { projects, isLastPage, start };
};
async function listBitbucketServerProjects(sourceUrl) {
    const bitbucketServerToken = get_bitbucket_server_token_1.getBitbucketServerToken();
    if (!sourceUrl) {
        throw new Error('Please provide required `sourceUrl` for Bitbucket Server source');
    }
    debug(`Fetching all projects data`);
    const projects = await fetchAllProjects(sourceUrl, bitbucketServerToken);
    return projects;
}
exports.listBitbucketServerProjects = listBitbucketServerProjects;
//# sourceMappingURL=list-projects.js.map