"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.listBitbucketServerRepos = exports.fetchAllRepos = void 0;
const debugLib = require("debug");
const get_bitbucket_server_token_1 = require("./get-bitbucket-server-token");
const request_with_rate_limit_1 = require("../../request-with-rate-limit");
const limiters_1 = require("../../limiters");
const debug = debugLib('snyk:bitbucket-server');
const fetchAllRepos = async (url, projectKey, token) => {
    let lastPage = false;
    let repoList = [];
    let pageCount = 1;
    let startFrom = 0;
    const limit = 100;
    while (!lastPage) {
        debug(`Fetching page ${pageCount} for ${projectKey}\n`);
        try {
            const { repos, isLastPage, start } = await getRepos(url, projectKey, token, startFrom, limit);
            repoList = repoList.concat(repos);
            lastPage = isLastPage;
            startFrom = start;
            pageCount++;
        }
        catch (err) {
            throw new Error(JSON.stringify(err));
        }
    }
    return repoList;
};
exports.fetchAllRepos = fetchAllRepos;
const getRepos = async (url, projectKey, token, startFrom, limit) => {
    let start = 0;
    const repos = [];
    const headers = { Authorization: `Bearer ${token}` };
    const limiter = await limiters_1.limiterForScm(1, 1000, 1000, 1000, 1000 * 3600);
    const { body, statusCode } = await request_with_rate_limit_1.limiterWithRateLimitRetries('get', `${url}/rest/api/1.0/repos?projectname=${projectKey}&state=AVAILABLE&start=${startFrom}&limit=${limit}`, headers, limiter, 60000);
    if (statusCode != 200) {
        throw new Error(`Failed to fetch repos for ${url}/rest/api/1.0/repos?projectname=${projectKey}&state=AVAILABLE&start=${startFrom}&limit=${limit}\n
    Status Code: ${statusCode}\n
    Response body: ${JSON.stringify(body)}`);
    }
    const { values, isLastPage, nextPageStart } = body;
    start = nextPageStart || -1;
    for (const repo of values) {
        if (repo.project.key === projectKey) {
            repos.push({ projectKey: repo.project.key, repoSlug: repo.name });
        }
    }
    return { repos, isLastPage, start };
};
async function listBitbucketServerRepos(projectName, host) {
    const bitbucketServerToken = get_bitbucket_server_token_1.getBitbucketServerToken();
    if (!host) {
        throw new Error('Please provide required `sourceUrl` for Bitbucket Server source');
    }
    debug(`Fetching all repos data for org: ${projectName}`);
    const repoList = await exports.fetchAllRepos(host, projectName, bitbucketServerToken);
    return repoList;
}
exports.listBitbucketServerRepos = listBitbucketServerRepos;
//# sourceMappingURL=list-repos.js.map