"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getGithubRepoMetaData = void 0;
const rest_1 = require("@octokit/rest");
const plugin_retry_1 = require("@octokit/plugin-retry");
const debugLib = require("debug");
const get_github_token_1 = require("./get-github-token");
const github_base_url_1 = require("./github-base-url");
const githubClient = rest_1.Octokit.plugin(plugin_retry_1.retry);
const debug = debugLib('snyk:get-github-defaultBranch-script');
async function getGithubRepoMetaData(target, host) {
    const githubToken = get_github_token_1.getGithubToken();
    const baseUrl = github_base_url_1.getGithubBaseUrl(host);
    const octokit = new githubClient({
        baseUrl,
        auth: githubToken,
    });
    debug(`Fetching default branch for repo: ${target.owner}/${target.name}`);
    const response = await octokit.repos.get({
        owner: target.owner,
        repo: target.name,
    });
    return {
        branch: response.data.default_branch,
        cloneUrl: response.data.clone_url,
        sshUrl: response.data.ssh_url,
        archived: response.data.archived,
    };
}
exports.getGithubRepoMetaData = getGithubRepoMetaData;
//# sourceMappingURL=get-repo-metadata.js.map