"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.listGitlabGroups = void 0;
const debugLib = require("debug");
const node_1 = require("@gitbeaker/node");
const get_token_1 = require("./get-token");
const get_base_url_1 = require("./get-base-url");
const debug = debugLib('snyk:github');
async function fetchOrgsForPage(client, pageNumber = 1) {
    const orgsData = [];
    const params = {
        perPage: 100,
        page: pageNumber,
    };
    const orgs = await client.Groups.all(params);
    const hasNextPage = orgs.length ? true : false;
    orgsData.push(...orgs.map((org) => ({
        name: org.full_path,
        id: org.id,
        url: org.web_url,
    })));
    return {
        orgs: orgsData,
        hasNextPage,
    };
}
async function fetchAllOrgs(client, page = 0) {
    const orgsData = [];
    let currentPage = page;
    let hasMorePages = true;
    while (hasMorePages) {
        currentPage = currentPage + 1;
        debug(`Fetching page ${currentPage}`);
        const { orgs, hasNextPage } = await fetchOrgsForPage(client, currentPage);
        orgsData.push(...orgs);
        hasMorePages = hasNextPage;
    }
    return orgsData;
}
async function listGitlabGroups(host) {
    const token = get_token_1.getToken();
    const baseUrl = get_base_url_1.getBaseUrl(host);
    const client = new node_1.Gitlab({ host: baseUrl, token });
    debug(`Fetching all Gitlab groups data from ${baseUrl}`);
    const orgs = await fetchAllOrgs(client);
    return orgs;
}
exports.listGitlabGroups = listGitlabGroups;
//# sourceMappingURL=list-groups.js.map