"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.listGitlabRepos = exports.fetchGitlabReposForPage = void 0;
const node_1 = require("@gitbeaker/node");
const debugLib = require("debug");
const get_token_1 = require("./get-token");
const get_base_url_1 = require("./get-base-url");
const debug = debugLib('snyk:list-repos-script');
async function fetchGitlabReposForPage(client, groupName, pageNumber = 1, perPage = 100) {
    const repoData = [];
    const params = {
        // eslint-disable-next-line @typescript-eslint/camelcase
        perPage,
        page: pageNumber,
        with_shared: false,
    };
    const projects = (await client.Groups.projects(groupName, params));
    const hasNextPage = projects.length < perPage ? false : true;
    debug(`Found ${projects.length} projects in ${groupName}`);
    for (const project of projects) {
        const { archived, namespace, default_branch, forked_from_project, path_with_namespace, id, } = project;
        if (groupName !== namespace.full_path) {
            debug(`Skipping project ${project.name_with_namespace} as it belong to another group`);
            continue;
        }
        if (archived || !default_branch) {
            debug(`Skipping project ${project.name_with_namespace} as it is either archived or has no default branch`);
            continue;
        }
        repoData.push({
            fork: forked_from_project ? true : false,
            name: path_with_namespace,
            id,
            branch: default_branch,
        });
    }
    return { repos: repoData, hasNextPage };
}
exports.fetchGitlabReposForPage = fetchGitlabReposForPage;
async function fetchAllRepos(client, groupName, page = 0) {
    const repoData = [];
    let currentPage = page;
    let hasMorePages = true;
    while (hasMorePages) {
        currentPage = currentPage + 1;
        debug(`Fetching page: ${currentPage}`);
        const { repos, hasNextPage } = await fetchGitlabReposForPage(client, groupName, currentPage);
        hasMorePages = hasNextPage;
        repoData.push(...repos);
    }
    return repoData;
}
async function listGitlabRepos(groupName, host) {
    const token = get_token_1.getToken();
    const baseUrl = get_base_url_1.getBaseUrl(host);
    const client = new node_1.Gitlab({ host: baseUrl, token });
    debug(`Fetching all repos data for org \`${groupName}\` from ${baseUrl}`);
    const repos = await fetchAllRepos(client, groupName);
    return repos;
}
exports.listGitlabRepos = listGitlabRepos;
//# sourceMappingURL=list-repos.js.map