import type { SnykProductEntitlement } from './supported-project-types/supported-manifests';
export interface ImportTarget {
    orgId: string;
    integrationId: string;
    target: Target;
    files?: FilePath[];
    exclusionGlobs?: string;
}
export interface CreatedOrg {
    name: string;
    created?: string;
    integrations: {
        [name: string]: string;
    };
    orgId: string;
    groupId: string;
    origName: string;
    sourceOrgId?: string;
}
export interface Target {
    name?: string;
    appId?: string;
    functionId?: string;
    slugId?: string;
    projectKey?: string;
    repoSlug?: string;
    id?: number;
    owner?: string;
    branch?: string;
}
export interface FilePath {
    path: string;
}
export interface CreateOrgData {
    groupId: string;
    name: string;
    sourceOrgId?: string;
}
export declare enum Status {
    PENDING = "pending",
    FAILED = "failed",
    COMPLETE = "complete"
}
export interface Project {
    targetFile?: string;
    success: boolean;
    projectUrl: string;
}
export interface Log {
    name: string;
    created: string;
    status: Status;
    projects: Project[];
}
export interface PollImportResponse {
    id: string;
    status: 'pending' | 'failed' | 'complete';
    created: string;
    logs: Log[];
}
export declare enum SupportedIntegrationTypesImportData {
    GITHUB = "github",
    GHE = "github-enterprise",
    GITLAB = "gitlab",
    AZURE_REPOS = "azure-repos",
    BITBUCKET_SERVER = "bitbucket-server",
    BITBUCKET_CLOUD = "bitbucket-cloud"
}
export declare enum SupportedIntegrationTypesImportOrgData {
    GITHUB = "github",
    GHE = "github-enterprise",
    GITLAB = "gitlab",
    BITBUCKET_SERVER = "bitbucket-server",
    BITBUCKET_CLOUD = "bitbucket-cloud"
}
export declare enum SupportedIntegrationTypesUpdateProject {
    GITHUB = "github",
    GHE = "github-enterprise"
}
export declare enum SupportedProductsUpdateProject {
    CONTAINER = "container",
    OPEN_SOURCE = "open-source",
    IAC = "iac"
}
export declare const productEntitlements: {
    [key in SupportedProductsUpdateProject]: SnykProductEntitlement;
};
export declare enum SupportedIntegrationTypesToListSnykTargets {
    GITHUB = "github",
    GHE = "github-enterprise",
    BITBUCKET_CLOUD = "bitbucket-cloud",
    GCR = "gcr",
    DOCKER_HUB = "docker-hub",
    GITLAB = "gitlab",
    AZURE_REPOS = "azure-repos",
    BITBUCKET_SERVER = "bitbucket-server"
}
export interface CommandResult {
    fileName: string | undefined;
    exitCode: number;
    message: string | undefined;
}
export interface SnykProject {
    name: string;
    id: string;
    created: string;
    origin: string;
    type: string;
    branch: string | null;
    status: 'inactive' | 'active';
}
export interface Org {
    name: string;
    id: string;
    slug: string;
    url: string;
    group: {
        name: string;
        id: string;
    };
}
export interface RESTProjectData {
    attributes: RESTProjectsAttributes;
    id: string;
    relationships: RESTProjectsRelationships;
    type: string;
}
export interface RESTProjectsAttributes {
    businessCriticality: string;
    created: string;
    environment: string;
    lifecycle: string;
    name: string;
    origin: string;
    status: 'inactive' | 'active';
    tags: unknown;
    targetReference: string | null;
    type: string;
}
export interface RESTProjectsRelationships {
    importingUser: RESTProjectsRelashionshipData;
    org: RESTProjectsRelashionshipData;
    owner: RESTProjectsRelashionshipData;
    target: RESTProjectsRelashionshipData;
}
export interface RESTProjectsRelashionshipData {
    data: {
        id: string;
        type: string;
    };
    links: {
        first?: string;
        last?: string;
        next?: string;
        prev?: string;
        related?: string;
        self?: string;
    };
    meta: unknown;
}
export interface SnykTargetRelationships {
    org: {
        data: {
            id: string;
            type: string;
        };
        links: {
            first?: string;
            last?: string;
            next?: string;
            prev?: string;
            related?: string;
            self?: string;
        };
        meta: unknown;
    };
}
export interface RepoMetaData {
    branch: string;
    cloneUrl: string;
    sshUrl: string;
    archived: boolean;
}
export interface SnykTarget {
    attributes: {
        displayName: string;
        isPrivate: boolean;
        origin: string;
        remoteUrl: string | null;
    };
    id: string;
    relationships: SnykTargetRelationships;
    type: string;
}
export interface RESTTargetResponse {
    data: SnykTarget[];
    jsonapi: {
        version: string;
    };
    links: {
        first?: string;
        last?: string;
        next?: string;
        prev?: string;
        related?: string;
        self?: string;
    };
}
export declare type SyncTargetsConfig = {
    dryRun: boolean;
    entitlements?: SnykProductEntitlement[];
    manifestTypes?: string[];
    exclusionGlobs?: string[];
};
export declare enum ProjectUpdateType {
    BRANCH = "branch",
    DEACTIVATE = "deactivate",
    IMPORT = "import"
}
