"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.logFailedProjects = void 0;
const bunyan = require("bunyan");
const debugLib = require("debug");
const common_1 = require("./../common");
const lib_1 = require("./../lib");
const debug = debugLib('snyk:import-projects-script');
async function logFailedProjects(projects, loggingPath = lib_1.getLoggingPath()) {
    try {
        const projectsPerOrg = {};
        projects.forEach((p) => {
            const orgId = p.locationUrl.split('/').slice(-5)[0];
            if (!projectsPerOrg[orgId]) {
                projectsPerOrg[orgId] = [p];
            }
            else {
                projectsPerOrg[orgId].push(p);
            }
        });
        for (const orgId in projectsPerOrg) {
            const log = bunyan.createLogger({
                name: 'snyk:import-projects-script',
                level: 'error',
                streams: [
                    {
                        level: 'error',
                        path: `${loggingPath}/${orgId}.${common_1.FAILED_PROJECTS_LOG_NAME}`,
                    },
                ],
            });
            projectsPerOrg[orgId].forEach((project) => {
                debug({ orgId, ...project }, 'Error importing project');
                log.error({ orgId, ...project }, 'Error importing project');
            });
        }
    }
    catch (e) {
        // do nothing
    }
}
exports.logFailedProjects = logFailedProjects;
//# sourceMappingURL=log-failed-projects.js.map