"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.logImportedTargets = void 0;
const bunyan = require("bunyan");
const _ = require("lodash");
const common_1 = require("./../common");
const lib_1 = require("./../lib");
const generate_target_id_1 = require("../generate-target-id");
async function logImportedTargets(targets, locationUrl, loggingPath = lib_1.getLoggingPath(), message = 'Target requested for import') {
    try {
        // only properties available on Target allowed here, must keep them in sync
        const log = bunyan.createLogger({
            name: 'snyk:import-projects-script',
            level: 'info',
            streams: [
                {
                    level: 'info',
                    path: `${loggingPath}/${common_1.IMPORT_LOG_NAME}`,
                },
            ],
        });
        for (const data of targets) {
            const { integrationId, target, orgId } = data;
            log.info({
                target: _.pick(target, ...common_1.targetProps),
                locationUrl,
                orgId,
                integrationId,
                targetId: generate_target_id_1.generateTargetId(orgId, integrationId, target),
            }, message);
        }
    }
    catch (e) {
        // do nothing
    }
}
exports.logImportedTargets = logImportedTargets;
//# sourceMappingURL=log-imported-targets.js.map