"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.cloneAndAnalyze = void 0;
const debugLib = require("debug");
const path = require("path");
const common_1 = require("../../common");
const lib_1 = require("../../lib");
const supported_manifests_1 = require("../../lib/supported-project-types/supported-manifests");
const generate_projects_diff_actions_1 = require("./generate-projects-diff-actions");
const delete_directory_1 = require("../../lib/delete-directory");
const debug = debugLib('snyk:clone-and-analyze');
async function cloneAndAnalyze(integrationType, repoMetadata, snykMonitoredProjects, config) {
    const { manifestTypes, entitlements = ['openSource'], exclusionGlobs = [], } = config;
    const manifestFileTypes = manifestTypes && manifestTypes.length > 0
        ? manifestTypes
        : supported_manifests_1.getSCMSupportedProjectTypes(entitlements);
    const { success, repoPath, gitResponse } = await lib_1.gitClone(integrationType, repoMetadata);
    debug('Clone response', { success, repoPath, gitResponse });
    if (!success) {
        throw new Error(gitResponse);
    }
    if (!repoPath) {
        throw new Error('No location returned for clones repo to analyze');
    }
    const { files } = await lib_1.find(repoPath, [...common_1.defaultExclusionGlobs, ...exclusionGlobs], 
    // TODO: when possible switch to check entitlements via API automatically for an org
    // right now the product entitlements are not exposed via API so user has to provide which products
    // they are using
    lib_1.getSCMSupportedManifests(manifestFileTypes, entitlements), 10);
    const relativeFileNames = files.map((f) => path.relative(repoPath, f));
    debug(`Detected ${files.length} files in ${repoMetadata.cloneUrl}: ${files.join(',')}`);
    try {
        await delete_directory_1.deleteDirectory(repoPath);
    }
    catch (error) {
        debug(`Failed to delete ${repoPath}. Error was ${error}.`);
    }
    return generate_projects_diff_actions_1.generateProjectDiffActions(relativeFileNames, snykMonitoredProjects, manifestFileTypes);
}
exports.cloneAndAnalyze = cloneAndAnalyze;
//# sourceMappingURL=clone-and-analyze.js.map