"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateProjectDiffActions = void 0;
const supported_manifests_1 = require("../../lib/supported-project-types/supported-manifests");
function generateProjectDiffActions(repoManifests, snykMonitoredProjects, manifestTypes = Object.keys(supported_manifests_1.OPEN_SOURCE_PACKAGE_MANAGERS)) {
    const filesToImport = [];
    const remove = [];
    // any files in the repo, not in Snyk already should be
    // imported
    for (const manifest of repoManifests) {
        const snykProjectManifests = snykMonitoredProjects.map((p) => p.name.split(':')[1]);
        if (!snykProjectManifests.includes(manifest)) {
            filesToImport.push(manifest);
        }
    }
    // any files in Snyk, not found in the repo should have the
    // related project deactivated
    for (const project of getSupportedProjectsToDeactivate(snykMonitoredProjects)) {
        const targetFile = project.name.split(':')[1];
        if (!targetFile) {
            continue;
        }
        if (!repoManifests.includes(targetFile)) {
            if (manifestTypes.includes(project.type)) {
                remove.push(project);
            }
        }
    }
    return {
        import: filesToImport,
        remove,
    };
}
exports.generateProjectDiffActions = generateProjectDiffActions;
// should return only projects that reference a manifest file in their name
function getSupportedProjectsToDeactivate(projects) {
    return projects
        .filter((p) => p.status !== 'inactive')
        .filter((p) => p.type !== 'sast');
}
//# sourceMappingURL=generate-projects-diff-actions.js.map