"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.streamJson = exports.streamData = void 0;
const debugLib = require("debug");
const fs = require("fs");
const split = require("split");
const debug = debugLib('streamData:load-file');
const debugSnyk = debugLib('snyk:load-file');
async function streamData(file, jsonKey) {
    let res;
    let parsedJson;
    debug('Trying to stream as minified JSON');
    const fileStream = fs.createReadStream(file);
    res = await streamJson(fileStream.pipe(split()));
    if (!res) {
        debug(`Failed to load as minified JSON, trying to load as beautified JSON with spaces`);
        res = await streamJson(fileStream);
    }
    try {
        const json = JSON.parse(res);
        parsedJson = json[jsonKey];
    }
    catch (e) {
        const err = `ERROR: Could not find "${jsonKey}" key in json. Make sure the JSON is valid and the key is present`;
        debugSnyk(err);
        debug(e.message);
        throw new Error(err);
    }
    return parsedJson;
}
exports.streamData = streamData;
async function streamJson(fileStream) {
    let data = '';
    return new Promise((resolve, reject) => {
        fileStream
            .on('data', (lineObj) => {
            if (!lineObj) {
                return;
            }
            data += lineObj;
        })
            .on('error', (err) => {
            debug('Failed to createReadStream for file: ' + err);
            return reject(err);
        })
            .on('end', async () => resolve(data));
    });
}
exports.streamJson = streamJson;
//# sourceMappingURL=stream-data.js.map